==> pcl-1.2_1.2.0.orig.tar.bz2: PCL-1.2.0-Source/filters/src/conditional_removal.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2010, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: conditional_removal.cpp 2617 2011-09-30 21:37:23Z rusu $
 *
 */

#include "pcl/impl/instantiate.hpp"
#include "pcl/point_types.h"
#include "pcl/filters/conditional_removal.h"
#include "pcl/filters/impl/conditional_removal.hpp"

// Instantiations of specific point types
PCL_INSTANTIATE(PointDataAtOffset, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(ComparisonBase, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(FieldComparison, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(PackedRGBComparison, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(PackedHSIComparison, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(ConditionBase, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(ConditionAnd, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(ConditionOr, PCL_XYZ_POINT_TYPES);
PCL_INSTANTIATE(ConditionalRemoval, PCL_XYZ_POINT_TYPES);

==> pcl-1.5_1.5.1.orig.tar.bz2: PCL-1.5.1-Source/filters/src/conditional_removal.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2010, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: conditional_removal.cpp 4702 2012-02-23 09:39:33Z gedikli $
 *
 */

#include "pcl/impl/instantiate.hpp"
#include "pcl/point_types.h"
#include "pcl/filters/conditional_removal.h"
#include "pcl/filters/impl/conditional_removal.hpp"

// Instantiations of specific point types
PCL_INSTANTIATE(PointDataAtOffset, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(ComparisonBase, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(FieldComparison, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(PackedRGBComparison, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(PackedHSIComparison, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(ConditionBase, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(ConditionAnd, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(ConditionOr, PCL_XYZ_POINT_TYPES)
PCL_INSTANTIATE(ConditionalRemoval, PCL_XYZ_POINT_TYPES)
